Crate revm_bytecode

Crate revm_bytecode 

Crate that contains bytecode types and opcode constants.

Legacy bytecode will always contain a jump table.

While EIP-7702 bytecode must contains a Address.

Re-exports

pub use bytecode::Bytecode;
pub use bytecode::BytecodeKind;
pub use opcode::OpCode;
pub use bitvec;

Modules

bytecode
Module that contains the bytecode struct with all variants supported by Ethereum mainnet.
eip7702
EIP-7702 bytecode. EIP-7702 bytecode constants and error types.
opcode
EVM opcode definitions and utilities. It contains opcode information and utilities to work with opcodes.
utils
Various utilities for the bytecode

Structs

BytecodeIterator
Iterator over opcodes in a bytecode, skipping immediates.
JumpTable
A table of valid jump destinations.

Enums

BytecodeDecodeError
Bytecode decode errors